@@ -3,7 +3,8 @@ from dataclasses import asdict
 from dateutil.parser import parse
 from flask import abort, json, jsonify, request, send_from_directory, Blueprint
 
-from paperead.repository.notes import Note, NoteMetadata
+from paperead.repository.notes import Note
+from . import buildDocument
 
 from paperead.env import env
 
@@ -48,12 +49,7 @@ def updateNote(id: str):
     if id not in env.repo:
         abort(404)
 
-    data: dict = request.get_json()
-    metadata = data.pop("metadata")
-    metadata["creation"] = parse(metadata["creation"])          # isoformat
-    metadata["modification"] = parse(metadata["modification"])  # isoformat
-    metaobj = NoteMetadata(**metadata)
-    obj = Note(metaobj, **data)
+    obj = buildDocument(Note, request.get_json())
 
     material = env.repo[id]
     material.notes.update(obj)
